# piGADM

piGADM (Python Interface to GADM data) is a package to use features for cartopy from the
[GADM](https://gadm.org/index.html) dataset. A command line interface can
be used to managed shapefile.


## Example

See the file `examples/example_FR.py`.

![Alt](/examples/example_FR.png)


## License

Copyright(c) 2022, 2023 Yoann Robin

This file is part of pigadm.

pigadm is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

pigadm is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with pigadm.  If not, see <https://www.gnu.org/licenses/>.


